==> vue-collapse-item-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/collapse-item/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import CollapseTransition from "@dftvue2-opentiny/vue-collapse-transition";
import { iconChevronRight } from "@dftvue2-opentiny/vue-icon";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["title", "titleRight", "name", "disabled"]),
  components: {
    CollapseTransition,
    IconChevronRight: iconChevronRight()
  },
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-collapse-item",
    class: {
      "is-active": _vm.state.isActive,
      "is-disabled": _vm.disabled
    }
  }, [_c("div", {
    attrs: {
      "role": "tab",
      "aria-expanded": _vm.state.isActive,
      "aria-controls": "tiny-collapse-content-" + _vm.state.id,
      "aria-describedby": "tiny-collapse-content-" + _vm.state.id
    }
  }, [_c("div", {
    staticClass: "tiny-collapse-item__header",
    class: {
      focusing: _vm.state.focusing,
      "is-active": _vm.state.isActive
    },
    attrs: {
      "role": "button",
      "id": "tiny-collapse-head-" + _vm.state.id,
      "tabindex": _vm.disabled ? void 0 : 0
    },
    on: {
      "keyup": function keyup($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "space", 32, $event.key, [" ", "Spacebar"]) && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter"))
          return null;
        $event.stopPropagation();
        return _vm.handleEnterClick.apply(null, arguments);
      },
      "focus": _vm.handleFocus,
      "blur": function blur($event) {
        _vm.state.focusing = false;
      }
    }
  }, [_c("div", {
    staticClass: "tiny-collapse-item__arrow",
    on: {
      "click": _vm.handleHeaderClick
    }
  }, [_vm._t("icon", function() {
    return [_c("icon-chevron-right", {
      staticClass: "tiny-svg-size",
      class: {
        "is-active": _vm.state.isActive
      }
    })];
  })], 2), _c("div", {
    staticClass: "tiny-collapse-item__word-overflow",
    on: {
      "click": _vm.handleHeaderClick
    }
  }, [_vm._t("title", function() {
    return [_vm._v(_vm._s(_vm.title))];
  })], 2), _c("div", {
    staticClass: "tiny-collapse-item__title__right"
  }, [_vm._t("title-right", function() {
    return [_vm._v(_vm._s(_vm.titleRight))];
  })], 2)]), _c("collapse-transition", [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.isActive,
      expression: "state.isActive"
    }],
    staticClass: "tiny-collapse-item__wrap",
    attrs: {
      "role": "tabpanel",
      "aria-hidden": !_vm.state.isActive,
      "aria-labelledby": "tiny-collapse-head-" + _vm.state.id,
      "id": "tiny-collapse-content-" + _vm.state.id
    }
  }, [_c("div", {
    staticClass: "tiny-collapse-item__content"
  }, [_vm._t("default")], 2)])])], 1)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-collapse-item-2.22.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/collapse-item/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import CollapseTransition from '@opentinyvue/vue-collapse-transition';
import { iconChevronRight } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["title", "titleRight", "name", "disabled", "expandIcon"]),
  components: {
    CollapseTransition,
    IconChevronRight: iconChevronRight()
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-collapse-item",
    class: {
      "is-active": _vm.state.isActive,
      "is-disabled": _vm.disabled
    }
  }, [_c("div", {
    attrs: {
      "role": "tab",
      "aria-expanded": _vm.state.isActive,
      "aria-controls": "tiny-collapse-content-" + _vm.state.id,
      "aria-describedby": "tiny-collapse-content-" + _vm.state.id
    }
  }, [_c("div", {
    staticClass: "tiny-collapse-item__header",
    class: {
      focusing: _vm.state.focusing,
      "is-active": _vm.state.isActive
    },
    attrs: {
      "role": "button",
      "id": "tiny-collapse-head-" + _vm.state.id,
      "tabindex": _vm.disabled ? void 0 : 0
    },
    on: {
      "keyup": function keyup($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "space", 32, $event.key, [" ", "Spacebar"]) && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter")) return null;
        $event.stopPropagation();
        return _vm.handleEnterClick.apply(null, arguments);
      },
      "focus": _vm.handleFocus,
      "blur": function blur($event) {
        _vm.state.focusing = false;
      },
      "click": _vm.handleHeaderContainerClick
    }
  }, [_c("div", {
    staticClass: "tiny-collapse-item__arrow",
    class: {
      "is-active": _vm.state.isActive
    },
    on: {
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.handleHeaderClick.apply(null, arguments);
      }
    }
  }, [_vm._t("icon", function() {
    return [_c(_vm.state.arrowIcon, {
      tag: "component",
      staticClass: "tiny-collapse-item__arrow-icon tiny-svg-size",
      class: {
        "is-active": _vm.state.isActive
      }
    })];
  })], 2), _c("div", {
    staticClass: "tiny-collapse-item__word-overflow",
    on: {
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.handleHeaderClick.apply(null, arguments);
      }
    }
  }, [_vm._t("title", function() {
    return [_vm._v(_vm._s(_vm.title))];
  })], 2), _c("div", {
    staticClass: "tiny-collapse-item__title__right"
  }, [_vm._t("title-right", function() {
    return [_vm._v(_vm._s(_vm.titleRight))];
  })], 2)]), _c("collapse-transition", [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.isActive,
      expression: "state.isActive"
    }],
    staticClass: "tiny-collapse-item__wrap",
    attrs: {
      "role": "tabpanel",
      "aria-hidden": !_vm.state.isActive,
      "aria-labelledby": "tiny-collapse-head-" + _vm.state.id,
      "id": "tiny-collapse-content-" + _vm.state.id
    }
  }, [_c("div", {
    staticClass: "tiny-collapse-item__content"
  }, [_vm._t("default")], 2)])])], 1)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
